@@ -1,9 +1,17 @@
 import math
+from enum import Enum, unique
 from typing import Dict, List
 
 from .layer_info import LayerInfo
 
 
+@unique
+class Verbosity(Enum):
+    """ Contains verbosity levels. """
+
+    QUIET, DEFAULT, VERBOSE = 0, 1, 2
+
+
 class FormattingOptions:
     """ Class that holds information about formatting the table output. """
 
