@@ -1,8 +1,9 @@
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Sequence, Union
 
 import numpy as np
+import torch
 
-from .formatting import FormattingOptions
+from .formatting import FormattingOptions, Verbosity
 from .layer_info import LayerInfo
 
 HEADER_TITLES = {
@@ -17,7 +18,10 @@ class ModelStatistics:
     """ Class for storing results of the summary. """
 
     def __init__(
-        self, summary_list: List[LayerInfo], input_size: List[Any], formatting: FormattingOptions
+        self,
+        summary_list: List[LayerInfo],
+        input_size: List[Union[int, Sequence[Any], torch.Size]],
+        formatting: FormattingOptions,
     ):
         self.summary_list = summary_list
         self.input_size = input_size
@@ -86,7 +90,7 @@ class ModelStatistics:
         depth = layer_info.depth
         name = (get_start_str(depth) if self.formatting.use_branching else "") + str(layer_info)
         new_line = self.formatting.format_row(name, row_values)
-        if self.formatting.verbose == 2:
+        if self.formatting.verbose == Verbosity.VERBOSE.value:
             for inner_name, inner_shape in layer_info.inner_layers.items():
                 prefix = get_start_str(depth + 1) if self.formatting.use_branching else "  "
                 extra_row_values = {"kernel_size": str(inner_shape)}
